==> djangoldp_needle-0.1.26-py3-none-any.whl: djangoldp_needle/request_parser/parsers/opengraph.py <==
from . import AbstractParser
from ...models import AnnotationTarget
from urllib.parse import urlparse


class OpenGraph(AbstractParser):
    def parse(self, annotation_target: AnnotationTarget, target_url, bs_document, previous_parse_result):
        # Does not change result if previous parse match
        # if previous_parse_result:
        #     return previous_parse_result

        # if og_url is None:
        #     return False

        # if og_image is None:
        #     return False

        # if og_title is None:
        #     return False
        if(bs_document.head) :
            if annotation_target.publication_date is None:
                og_published = bs_document.head.find('meta', property="og:article:published_time")
                if og_published is not None:
                    annotation_target.publication_date = og_published['content']
                else:
                    og_published = bs_document.head.find('meta', property="og:updated_time")
                    if og_published is not None:
                        annotation_target.publication_date = og_published['content']

            if annotation_target.target is None or len(annotation_target.target.strip()) == 0:
                og_url = bs_document.head.find('meta', property="og:url")
                if og_url:
                    annotation_target.target = og_url['content']

            if annotation_target.image is None or len(annotation_target.image.strip()) == 0:
                og_image = bs_document.head.find('meta', property="og:image")
                if og_image:
                    value = og_image['content'];
                    if value.startswith('/'):
                        og_url = bs_document.head.find('meta', property="og:url")
                        if og_url:
                            parsed_uri = urlparse(og_url['content'])
                            host = '{uri.scheme}://{uri.netloc}'.format(uri=parsed_uri)
                            annotation_target.image = host + value
                    else :
                        annotation_target.image = value

            if annotation_target.title is None or len(annotation_target.title.strip()) == 0:
                og_title = bs_document.head.find('meta', property="og:title")
                if og_title:
                    annotation_target.title = og_title['content']

        return True

==> djangoldp_needle-0.1.27-py3-none-any.whl: djangoldp_needle/request_parser/parsers/opengraph.py <==
from . import AbstractParser
from . import JSONLD
from ...models import AnnotationTarget
from urllib.parse import urlparse


class OpenGraph(AbstractParser):
    def parse(self, annotation_target: AnnotationTarget, target_url, bs_document, previous_parse_result):
        # Does not change result if previous parse match
        # if previous_parse_result:
        #     return previous_parse_result

        # if og_url is None:
        #     return False

        # if og_image is None:
        #     return False

        # if og_title is None:
        #     return False
        if(bs_document.head) :
            if annotation_target.publication_date is None:
                og_published = bs_document.head.find('meta', property="og:article:published_time")
                if og_published is not None:
                    annotation_target.publication_date = JSONLD().try_strptimeAll(og_published['content'])
                else:
                    og_published = bs_document.head.find('meta', property="og:updated_time")
                    if og_published is not None:
                        annotation_target.publication_date = JSONLD().try_strptimeAll(og_published['content'])

            if annotation_target.target is None or len(annotation_target.target.strip()) == 0:
                og_url = bs_document.head.find('meta', property="og:url")
                if og_url:
                    annotation_target.target = og_url['content']

            if annotation_target.image is None or len(annotation_target.image.strip()) == 0:
                og_image = bs_document.head.find('meta', property="og:image")
                if og_image:
                    value = og_image['content'];
                    if value.startswith('/'):
                        og_url = bs_document.head.find('meta', property="og:url")
                        if og_url:
                            parsed_uri = urlparse(og_url['content'])
                            host = '{uri.scheme}://{uri.netloc}'.format(uri=parsed_uri)
                            annotation_target.image = host + value
                    else :
                        annotation_target.image = value

            if annotation_target.title is None or len(annotation_target.title.strip()) == 0:
                og_title = bs_document.head.find('meta', property="og:title")
                if og_title:
                    annotation_target.title = og_title['content']

        return True
